<?php
/**
 * EDD Customer Dashboard
 *
 * @package   EDD_Customer_Dashboard
 * @author    Josh Mallard <josh@limecuda.com>
 * @license   GPL-2.0+
 * @link      http://joshmallard.com
 */

/**
 * EDD Customer Dashboard Class
 *
 * @package EDD_Customer_Dashboard
 * @author  Josh Mallard <josh@limecuda.com>
 */
class EDD_Customer_Dashboard {

	/**
	 * Plugin version, used for cache-busting of style and script file references.
	 *
	 * @since   1.0.0
	 *
	 * @var     string
	 */
	const VERSION = '1.0.0';

	/**
	 * text-domain variable
	 *
	 * @since    1.0.0
	 *
	 * @var      string
	 */
	protected $plugin_slug = 'edd_customer_dashboard';

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Initialize the plugin by setting localization and loading public scripts
	 * and styles.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		// Load plugin text domain
		add_action( 'init', array( $this, 'load_plugin_textdomain' ) );

		// Load public-facing style sheet and JavaScript.
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_styles' ) );

		add_shortcode( 'edd_customer_dashboard', array( $this, 'edd_customer_dashboard_shortcode' ) );

	}

	/**
	 * Return the plugin slug.
	 *
	 * @since    1.0.0
	 *
	 * @return    Plugin slug variable.
	 */
	public function get_plugin_slug() {
		return $this->plugin_slug;
	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Load the plugin text domain for translation.
	 *
	 * @since    1.0.0
	 */
	public function load_plugin_textdomain() {

		$domain = $this->plugin_slug;
		$locale = apply_filters( 'plugin_locale', get_locale(), $domain );

		load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . $domain . '/' . $domain . '-' . $locale . '.mo' );
		load_plugin_textdomain( $domain, FALSE, basename( plugin_dir_path( dirname( __FILE__ ) ) ) . '/languages/' );

	}

	/**
	 * Register and enqueue public-facing style sheet.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_slug . '-plugin-styles', plugins_url( 'style.css', __FILE__ ), array(), self::VERSION );
	}

	/**
	 * Build the dashboard shortcode
	 *
	 * @since 1.0.0
	 */
	public function edd_customer_dashboard_shortcode( $atts, $content = "" ) {

		ob_start();

		if( is_user_logged_in() ) {

			$menu_items = $this->build_menu();
			$dashboard_content = $this->build_page_content();

			// Customer dashboard menu
			do_action( 'edd_cd_before_menu' );
			include_once( plugin_dir_path( __FILE__ ) . '/templates/customer-dashboard-menu.php' );
			do_action( 'edd_cd_after_menu' );

			?>
			<div class="customer-dashboard-content">
				<?php
				do_action( 'edd_cd_before_content' );

				echo $dashboard_content;

				do_action( 'edd_cd_after_content' );
				?>
			</div>

			<?php
		} else {
			echo edd_login_form( get_permalink() );
		}

		$dashboard = ob_get_clean();

		return $dashboard;

	}
	/**
	* Get the total spent for a customer.
	* When no customer is passed into the function, it will get the currently logged in user's total spent
	*
	* Usage <?php echo sumobi_edd_get_total_spent_for_customer( $user_id ); ?>
	*/
	public function sumobi_edd_get_total_spent_for_customer( $user_id = '' ) {
		
		// if no user ID is passed in, default to the currently logged in user
		if ( ! $user_id ) {
			$user_id = get_current_user_id();
		}
	
		// get customers
		$customers = EDD()->customers->get_customers(
			array( 
				'number'  => -1,
				'user_id' => $user_id
			)
		);
	
		// get customers purchase values
		$purchase_values = array();
	
		if ( $customers ) {
			foreach ( $customers as $customer ) {
				$purchase_values[] = $customer->purchase_value;
			}
		}
		
		// get the total spent and format it
		$total_spent = edd_currency_filter( edd_format_amount( array_sum( $purchase_values ) ) );
	
		// return the amount the customer has spent
		return $total_spent;
	} 

	/**
	 * Customer dashboard menu items
	 *
	 * @since    1.0.0
	 * @return   array
	 */
	public function build_menu() {
		$menu = array();
		
		$menu[ 'dashboard' ] = array(
			'icon' => 'fa fa-tachometer lg',
			'task' => 'dashboard',
			'name' => __( 'dashboard', 'edd_customer_dashboard' )
		);

		$menu[ 'profile' ] = array(
			'icon' => 'fa fa-user lg',
			'task' => 'profile',
			'name' => __( 'Profile', 'edd_customer_dashboard' )
		);

		$menu[ 'purchases' ] = array(
			'icon' => 'fa fa-suitcase lg',
			'task' => 'purchases',
			'name' => __( 'Purchase History', 'edd_customer_dashboard' )
		);

		$menu[ 'downloads' ] = array(
			'icon' => 'fa fa-download lg',
			'task' => 'download',
			'name' => __( 'Downloads', 'edd_customer_dashboard' )
		);
		// Support for EDD Wallet
		if( class_exists( 'EDD_Wallet' ) ) {
			$menu[ 'wallet' ] = array(
				'icon' => 'fa fa-credit-card lg',
				'task'=> 'wallet',
				'name' => __( 'wallet', 'edd_customer_dashboard' )
			);
		}
		// Support for EDD Wishlists
		if( class_exists( 'EDD_Wish_Lists' ) ) {
			$menu[ 'wishlists' ] = array(
				'icon' => 'fa fa-heart',
				'task'=> 'wishlist',
				'name' => __( 'Wishlists', 'edd_customer_dashboard' )
			);
		}
		
		$menu[ 'fes_vendors' ] = array(
			'icon' => 'fa fa-download lg',
			'task' => 'vendors',
			'name' => __( 'Vendors Page', 'edd_customer_dashboard' )
		);
		

		$menu = apply_filters( "edd_customer_dashboard_menu_links", $menu );
		return $menu;

	}

	/**
	 * Customer dashboard page content
	 *
	 * @since	1.0.0
	 */
	public function build_page_content() {
		$task = !empty( $_GET[ 'task' ] ) ? $_GET[ 'task' ] : 'dashboard';
		
		ob_start();
		if ( ! $user_id ) {
			$user_id = get_current_user_id();
		}
		$customer = new EDD_Customer( $user_id );

		$payments = $customer->purchase_value;
		$payments = floor($payments);
		$pay_count = $customer->purchase_count;
		
		/*$total_spent = sumobi_edd_get_total_spent_for_customer( $user_id );*/
	
		$custom = apply_filters('edd_cd_custom_task', false, $task );
		switch ( $task ) {
			
			case 'dashboard' :
				echo '<h3>' . __( 'Public View','edd_customer_dashboard') . '</h3><br>';
				echo '<div class="stat-board">';
				echo '<div class="payments-box"><label>' . __( 'your Total purchase amount ','edd_customer_dashboard'). '</label><p>' . $payments . '</p></div>'; 
				echo '<div class="counts-box"><label>' . __( 'Number of your purchases ','edd_customer_dashboard') . '</label><p>' . $pay_count . '</p></div>'; 
				echo '</div>';
				
				echo '<b>' . __( 'your purchases','edd_customer_dashboard') . '</b><br>';
				if ($pay_count >=1) {
					echo do_shortcode( '[purchase_history]' );
					} else 
					{
						echo __( 'There is no Records up to now. Please first perform a purchase to see something here','edd_customer_dashboard');
				}
				echo '<br><br><b>' . __( 'your download files','edd_customer_dashboard') . '</b><br><br>';
				if ($pay_count >=1) {
					echo do_shortcode( '[download_history]' );
					} else {
						echo __( 'No download file Exists','edd_customer_dashboard');
					}
				echo '<br><br><b>' . __( 'your wallet deposit','edd_customer_dashboard') . '</b><br><br>';
				echo do_shortcode( '[edd_wallet_value]' );
				echo '<br><br><br><b>' . __( 'We are happy to be with you','edd_customer_dashboard') . '</b><br><br>';
			break;

			case 'profile' :
				echo '<h3>' . __( 'Profile','edd_customer_dashboard') . '</h3>';
				echo do_shortcode( '[edd_profile_editor]' );
			break;

			case 'purchases' :
				echo '<h3>' . __( 'Purchase History', 'edd_customer_dashboard' ) . '</h3>';
				echo do_shortcode( '[purchase_history]' );
			break;

			case 'download' :
				echo '<h3>' . __( 'Download History', 'edd_customer_dashboard' ) . '</h3>';
				echo do_shortcode( '[download_history]' );
			break;
			
			case 'wallet' :
				echo '<h3>' . __( 'your wallet', 'edd_customer_dashboard' ) . '</h3>';
				echo do_shortcode( '[edd_wallet_value]' );
				echo '<h3>Make Deposit</h3>';
				echo do_shortcode('[edd_deposit]');				
			break;
			
			case 'wishlist' :
				echo '<h3>' . __( 'Wishlists', 'edd_customer_dashboard' ) . '</h3>';
				echo do_shortcode( '[edd_wish_lists]' );
			break;

			case 'vendors' :
				echo '<h3>' . __( 'Vendors', 'edd_customer_dashboard' ) . '</h3>';
				echo do_shortcode( '[fes_login_registration_form]' );
			break;

			case $custom :
				do_action( 'edd_cd_custom_task_content' );
			break;

			default :

			break;

		}

		$dashboard_content = ob_get_clean();

		return $dashboard_content;

	}

}
